@@ -16,12 +16,19 @@ __all__ = [
     'Format',
 
     'apply_filters',
-    'ljust_fmtd',
-    'rjust_fmtd',
-    'center_fmtd',
     'StringFilter',
     'ReplaceCSI',
     'ReplaceSGR',
     'ReplaceNonAsciiBytes',
+
+    'ljust_fmtd',
+    'rjust_fmtd',
+    'center_fmtd',
+
+    'fmt_prefixed_unit',
+    'fmt_time_delta',
+    'fmt_auto_float',
+    'PrefixedUnitFmtPreset',
+    'TimeDeltaFmtPreset',
 ]
-__version__ = '1.7.3'
+__version__ = '1.7.4'
